version 14.1
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
	log close 
	}
log using exercise04cr.log, text replace


/*		****************************************************************	*/
/*     	File Name:		exercise04cr.do										*/
/*     	Date:   		May 3, 2019											*/
/*      Author: 		Frederick J. Boehmke								*/
/*      Purpose:		Analyze NAFTA position taking with competing risks.	*/
/*      Input File:		exercise04cr.dta									*/
/*      Output File:	exercise04cr.log,									*/	
/*      				exercise04cr-surv-yes.dta,							*/	
/*      				exercise04cr-surv-no.dta,							*/
/*      				exercise04cr.gph,									*/
/*						exercise04cr-table.txt								*/
/*      Requires:		estout.ado											*/		
/*		****************************************************************	*/

	/************************************************/
	/* Read in the data, summarize, and -stset- it.	*/
	/************************************************/

	
use exercise04cr, clear

  summarize

  stset timing
  
	stsum
	stdescribe
	
	sts graph, hazard ci
	sts graph, survival ci

  
	/************************************************/
	/* Run the non-competing risks version.			*/
	/************************************************/


streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, dist(weibull) nohr
stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr

  estimates store nocr

  
	/************************************************/
	/* Set up and run the competing risks version, 	*/
	/* for stating support and stating opposition.	*/
	/************************************************/

tab vote

		/* vote=1 corresponds to opposition. */
	
stset timing, failure(vote==1)

stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr

	estimates store cr_no
  
	stcurve, surv at1(mexbordr=0) at2(mexbordr=1) outfile(exercise04cr-surv-yes, replace) 
	
		/* vote=1 corresponds to support. */
	
stset timing, failure(vote==0)

stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr

	estimates store cr_yes

	stcurve, surv at1(mexbordr=0) at2(mexbordr=1) outfile(exercise04cr-surv-no, replace)


	/************************************************/
	/* Create a table comparing the results. 		*/
	/************************************************/
	
	
estout nocr cr_no cr_yes using exercise04cr-table.txt, replace ///
	cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.10 ** 0.05) /// 
	stats(N ll, fmt(0 2) label("Observations" "Log-Likelihood")) /// 
	varlabels(_cons constant) ///
	mlabels(Fail "Fail=Yes" "Fail=No") collabels(, none) ///
	mgroups("One Risk" "Competing Risks", pattern(1 1 0)) ///
	label varwidth(25) modelwidth(8) 
	
  
	/*******************************************************/
	/* Plot the two survival functions against each other. */
	/*******************************************************/
	

use exercise04cr-surv-no, clear

	rename surv2 surv_no_mexb_0
	rename surv3 surv_no_mexb_1

append using exercise04cr-surv-yes

	rename surv2 surv_yes_mexb_0
	rename surv3 surv_yes_mexb_1
	
twoway line surv_no_mexb_0 surv_no_mexb_1 surv_yes_mexb_0 surv_yes_mexb_1 _t, scheme(s1color) ///
	lcolor(blue blue red red) lpattern(solid dash solid dash) ///
	xlabel(#7) ylabel(#7, grid) ///
	xtitle(Days since First Announcement) ///
	legend(label(1 "Off Mexican Border - Vote Against") label(2 "On Mexican Border - Vote Against") ///
	  label(3 "Off Mexican Border - Vote For") label(4 "On Mexican Border - Vote For") rows(4) ring(0) bplace(sw)) ///
	saving(exercise04cr-survivor, replace)

log close
clear
exit, STATA

